@@ -261,8 +261,8 @@ RECURSE_BEGIN(obj, border) \
     } else { \
       unsigned found = 0; \
       /* Try to find a fitting rectangle */ \
-      for (rows = (unsigned) floor(sqrt(numsubobjs)); \
-	   rows >= (unsigned) ceil(pow(numsubobjs,0.33)) && rows > 1; \
+      for (rows = (unsigned) (float) floor(sqrt(numsubobjs)); \
+	   rows >= (unsigned) (float) ceil(pow(numsubobjs,0.33)) && rows > 1; \
 	   rows--) { \
         columns = numsubobjs / rows; \
         if (columns > 1 && columns * rows == numsubobjs) { \
